import React from 'react';
import { Link } from '@inertiajs/react';
import { Card, CardContent, CardDescription, CardFooter, CardHeader, CardTitle } from "@/components/ui/card";
import { Button } from "@/components/ui/button";
import { Calendar, ChevronRight } from 'lucide-react';

const blogPosts = [
  {
    id: 1,
    title: "Top 10 Places to Visit in Sri Lanka",
    excerpt: "From pristine beaches to misty mountains, discover the must-visit destinations in Sri Lanka that will take your breath away.",
    author: "Rajith Perera",
    date: "2025-04-02",
    image: "https://images.unsplash.com/photo-1589308078059-be1415eab4c3",
    category: "Travel Guide"
  },
  {
    id: 2,
    title: "Sri Lankan Cuisine: A Flavorful Journey",
    excerpt: "Explore the rich and diverse flavors of Sri Lankan cuisine, from spicy curries to sweet desserts that will tantalize your taste buds.",
    author: "Amaya Fernando",
    date: "2025-03-15",
    image: "https://images.unsplash.com/photo-1606471191009-63994c53433b",
    category: "Food & Culture"
  },
  {
    id: 3,
    title: "Wildlife Safari: Spotting Leopards in Yala National Park",
    excerpt: "Tips and tricks for maximizing your chances of spotting the elusive Sri Lankan leopard during your wildlife safari adventure.",
    author: "Dinesh Silva",
    date: "2025-02-28",
    image: "https://images.unsplash.com/photo-1549366021-9f761d450615",
    category: "Wildlife"
  },
  {
    id: 4,
    title: "Sustainable Tourism in Sri Lanka",
    excerpt: "How travelers can contribute to preserving Sri Lanka's natural beauty and cultural heritage through responsible tourism practices.",
    author: "Priya Wickramasinghe",
    date: "2025-02-10",
    image: "https://images.unsplash.com/photo-1588668214407-6ea9a6d8c272",
    category: "Eco-Tourism"
  },
  {
    id: 5,
    title: "Ancient Ruins: Exploring Sri Lanka's Cultural Triangle",
    excerpt: "Journey through time as we explore the ancient cities of Anuradhapura, Polonnaruwa, and Sigiriya - the heart of Sri Lanka's rich history.",
    author: "Rajith Perera",
    date: "2025-01-20",
    image: "https://images.unsplash.com/photo-1593693397690-362cb9666fc2",
    category: "History"
  },
  {
    id: 6,
    title: "The Perfect 7-Day Sri Lanka Itinerary",
    excerpt: "Make the most of your week in Sri Lanka with this carefully crafted itinerary covering the island's most remarkable attractions.",
    author: "Amaya Fernando",
    date: "2025-01-05",
    image: "https://images.unsplash.com/photo-1593693397690-362cb9666fc2",
    category: "Travel Guide"
  }
];

const formatDate = (dateString: string | number | Date) => {
  const date = new Date(dateString);
  return new Intl.DateTimeFormat('en-US', { 
    year: 'numeric', 
    month: 'long', 
    day: 'numeric' 
  }).format(date);
};

const BlogList = () => {
  return (
    <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-8">
      {blogPosts.map((post) => (
        <Card key={post.id} className="hover-float overflow-hidden border-0 shadow-md hover:shadow-xl transition-all duration-300 h-full flex flex-col">
          <div className="h-48 overflow-hidden">
            <img 
              src={post.image} 
              alt={post.title} 
              className="w-full h-full object-cover transition-transform duration-500 hover:scale-110"
            />
          </div>
          <div className="absolute top-4 right-4 bg-primary text-white text-xs font-bold px-3 py-1 rounded-full">
            {post.category}
          </div>
          <CardHeader>
            <div className="flex items-center text-sm text-gray-500 mb-2">
              <Calendar size={14} className="mr-1" />
              <span>{formatDate(post.date)}</span>
            </div>
            <CardTitle className="text-xl font-display">{post.title}</CardTitle>
            <CardDescription className="line-clamp-3">{post.excerpt}</CardDescription>
          </CardHeader>
          <CardFooter className="pt-0 mt-auto">
            <Button variant="ghost" className="text-primary hover:text-primary/80 p-0 flex items-center" asChild>
              <Link href={`/blog/${post.id}`}>
                Read More <ChevronRight size={16} className="ml-1" />
              </Link>
            </Button>
          </CardFooter>
        </Card>
      ))}
    </div>
  );
};

export default BlogList;
export { blogPosts, formatDate };